@@ -48,8 +48,10 @@ class ZoneImportAPIv2Adapter(base.APIv2Adapter):
             object, *args, **kwargs)
 
         if obj['zone_id'] is not None:
-            obj['links']['zone'] = \
-                '%s/v2/%s/%s' % (cls.BASE_URI, 'zones', obj['zone_id'])
+            obj['links']['zone'] = (
+                '%s/v2/%s/%s' % (cls._get_base_url(kwargs['request']), 'zones',
+                                 obj['zone_id'])
+            )
 
         return obj
 
