@@ -11,11 +11,9 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-from oslo_log import log as logging
 
 from designate.objects.adapters.api_v2 import base
 from designate import objects
-LOG = logging.getLogger(__name__)
 
 
 class ZoneTransferAcceptAPIv2Adapter(base.APIv2Adapter):
@@ -35,9 +33,7 @@ class ZoneTransferAcceptAPIv2Adapter(base.APIv2Adapter):
                 'read_only': False
             },
             "status": {},
-            "zone_id": {
-                'rename': 'zone_id',
-            },
+            "zone_id": {},
             "created_at": {},
             "updated_at": {},
         },
@@ -53,8 +49,10 @@ class ZoneTransferAcceptAPIv2Adapter(base.APIv2Adapter):
         obj = super(ZoneTransferAcceptAPIv2Adapter, cls)._render_object(
             object, *args, **kwargs)
 
-        obj['links']['zone'] = \
-            '%s/v2/%s/%s' % (cls.BASE_URI, 'zones', obj['zone_id'])
+        obj['links']['zone'] = (
+            '%s/v2/%s/%s' % (cls._get_base_url(kwargs['request']), 'zones',
+                             obj['zone_id'])
+        )
 
         return obj
 
